@@ -1,17 +1,12 @@
-use boostvoronoi::builder as VB;
+use boostvoronoi::prelude::*;
 use boostvoronoi::BvError;
 
+mod common;
+use common::almost_equal;
+
 type I = i32;
 type F = f64;
 
-fn almost_equal(x1: F, x2: F, y1: F, y2: F) -> bool {
-    let delta = 0.0001;
-    assert!(F::abs(x1 - x2) < delta, "{} != {}", x1, x2);
-    assert!(F::abs(y1 - y2) < delta, "{} != {}", y1, y2);
-
-    (F::abs(x1 - x2) < delta) && (F::abs(y1 - y2) < delta)
-}
-
 //#[ignore]
 #[test]
 /// four segments in a loop + one more
@@ -25,15 +20,14 @@ fn two_segments_9() -> Result<(), BvError> {
             [400, 200, 200, 200],
             [529, 242, 367, 107],
         ];
-        //let s = segments.iter().map(|x|x.into()).collect();
 
-        let _v = VB::to_points::<I, I>(&points);
-        let _s = VB::to_segments::<I, I>(&segments);
-
-        let mut vb = VB::Builder::<I, F>::default();
-        vb.with_vertices(_v.iter()).expect("two_segments_9");
-        vb.with_segments(_s.iter()).expect("two_segments_9");
-        vb.build().expect("two_segments_9")
+        Builder::<I, F>::default()
+            .with_vertices(points.iter())
+            .expect("two_segments_9")
+            .with_segments(segments.iter())
+            .expect("two_segments_9")
+            .build()
+            .expect("two_segments_9")
     };
     let v = output.vertices()[0].get();
     assert!(almost_equal(v.x(), 200.0000000, v.y(), 200.0000000));
